#!/bin/sh
# Last modified 2022-09-23

# Set a variable for the application name
APP="Connect Fonts"

##
## Displays some information about the script
##

cat <<LETTERHEAD
*
* Connect Fonts session cleaning script
* This removes preferences and session information for Connect Fonts v23
* on Mac OS X 10.15 through macOS 12
* 
LETTERHEAD

# Stop the application
echo "Shutting down the $APP application..."
CF_APP=$(pgrep -f "Connect Fonts.app/Contents/MacOS/Connect Fonts")
if [ -n "$CF_APP" ]; then
    kill -s HUP "$CF_APP" > /dev/null 2>&1
	# Sleep for a few seconds to let things shut down completely
	sleep 5
	if [ -n "$CF_APP" ]; then
		kill -s KILL "$CF_APP" > /dev/null 2>&1
		sleep 5
	fi
fi

echo "Done"

# Stop the QuickMatch process (FMRenderer)
echo "Shutting down FMRenderer..."

QM_PROCESS=$(pgrep -f "Connect Fonts.app/Contents/Resources/FMRenderer")
if [ -n "$QM_PROCESS" ]; then
	kill -s HUP "$QM_PROCESS" > /dev/null 2>&1
	sleep 3
	if [ -n "$QM_PROCESS" ]; then
		kill -s KILL "$QM_PROCESS" > /dev/null 2>&1
		sleep 3
	fi
fi

echo "Done"

# Stop the FMCore process
echo "Shutting down the $APP type core..."

# There shouldn't be more than one FMCore running but in some cases a second one gets started
# So we check for that now
FMCORES=$(pgrep -f "Connect Fonts.app/Contents/Resources/FMCore")
while [ -n "$FMCORES" ]; do
	killall -HUP FMCore
	sleep 5
	FMCORES=$(pgrep -f "Connect Fonts.app/Contents/Resources/FMCore")
	if [ -n "$FMCORES" ]; then
		echo "Type core did not shut down, killing type core"
		killall -KILL FMCore > /dev/null 2>&1
		sleep 3
	fi
done

echo "Done"

##
## Remove user preferences and session files for the current user account
##

echo "Removing $APP preferences and session files for the current user account..."

rm -rf "$HOME/Library/Extensis/com.extensis.FMCore-LaunchInfo.conf" > /dev/null 2>&1
# Remove application cache and session information
rm -rf "$HOME/.Extensis" > /dev/null 2>&1
rm -rf "$HOME/Library/Caches/FMCore" > /dev/null 2>&1
rm -rf "$HOME/Library/Caches/com.extensis.FMCore" > /dev/null 2>&1
rm -rf "$HOME/Library/Caches/com.extensis.SuitcaseFusion" > /dev/null 2>&1
rm -rf "$HOME/Library/WebKit/com.extensis.SuitcaseFusion" > /dev/null 2>&1

if [ -e "$HOME/Library/Preferences/com.extensis.SuitcaseFusion.plist" ]; then
	# Capture the vault location because users who migrated from Suitcase Fusion
	# will have their vault in the wrong place
	echo "Getting the vault location..."
	VAULT_LOC=$(defaults read com.extensis.SuitcaseFusion vault.path)
	# Remove the contents of the prefs file
	echo "Removing the $APP preferences..."
	defaults delete com.extensis.SuitcaseFusion
	# Put the vault location back
	echo "Restoring the vault location..."
	defaults write com.extensis.SuitcaseFusion vault.path "$VAULT_LOC"
fi

echo "Preference and session files for $APP have been removed. You can close this window."

exit
